@@ -151,7 +151,7 @@ class ProviderModel(object):
         self.session_success += 1
 
     def set_inactive(self):
-        # self.status = False
+        self.status = False
         # self.ssm_client.set_providers(self.to_json())
         pass
 
